@@ -133,6 +133,12 @@ def sw_main(task, _inputs, _asset):
     class Context:
         asset = _asset
         inputs = _inputs
+
+    # We did a big dumb and defaulted kwargs to {} in BasicRestEndpoint, which is a mutable object.
+    #  Because kwargs is mutable, every test is modifying the same kwargs if it only does updates.
+    #  This resets kwargs back to an empty dict after every test so we don't carry values over to subsequent tests
+    if getattr(mod.SwMain, "kwargs", False):
+        mod.SwMain.kwargs.clear()
     ctx = mod.SwMain(Context)
     return ctx
 
@@ -152,15 +158,6 @@ class TestStandardRest:
         self.config.update(self.test_config)
         self.ctx = self.cls(task, test)
 
-        yield
-        # Test cleanup after yield
-        # We did a big dump and default kwargs to {} in BasicRestEndpoint, which is a mutable object.
-        #  Because kwargs is mutable, every test is modifying the same kwargs if it only does updates.
-        #  This resets kwargs back to an empty dict after every test so we don't carry values over to subsequent tests
-        if getattr(self.ctx, "kwargs", False):
-            self.ctx.kwargs.clear()
-
-
     @mock_session
     def cls(self, task, test):
         """Instantiate SwMain for general tests"""
@@ -232,6 +229,6 @@ class TestStandardRest:
                             assert False, f'Output Key: {k}, Type: {_type}\nValue: {v}'
                     else:
                         missing.append(k)
-        if missing:
+        if missing and self.config.get("allow_missing_outputs") is not True:
             assert False, f'Manifest is missing outputs: {missing}'
         return True
